@@ -36,8 +36,8 @@ class SimpleFavoritesModel : public AbstractModel
     Q_PROPERTY(int dropPlaceholderIndex READ dropPlaceholderIndex WRITE setDropPlaceholderIndex NOTIFY dropPlaceholderIndexChanged)
 
     public:
-        explicit SimpleFavoritesModel(QObject *parent = 0);
-        ~SimpleFavoritesModel();
+        explicit SimpleFavoritesModel(QObject *parent = nullptr);
+        ~SimpleFavoritesModel() override;
 
         QString description() const override;
 
