@@ -150,15 +150,11 @@ FolderModel::FolderModel(QObject *parent) : QSortFilterProxyModel(parent),
     m_dirModel->setDirLister(dirLister);
     m_dirModel->setDropsAllowed(KDirModel::DropOnDirectory | KDirModel::DropOnLocalExecutable);
 
-    // If we have dropped items queued for moving, go unsorted now.
-    connect(this, &QAbstractItemModel::rowsAboutToBeInserted,
-            this, [this]() {
-            if (!m_dropTargetPositions.isEmpty()) {
-                setSortMode(-1);
-            }
-    });
-
-    // Position dropped items at the desired target position.
+    /*
+     * position dropped items at the desired target position
+     * delay this via queued connection, such that the row is available and can be mapped
+     * when we emit the move request
+     */
     connect(this, &QAbstractItemModel::rowsInserted,
             this, [this](const QModelIndex &parent, int first, int last) {
         for (int i = first; i <= last; ++i) {
@@ -168,11 +164,11 @@ FolderModel::FolderModel(QObject *parent) : QSortFilterProxyModel(parent),
             if (it != m_dropTargetPositions.end()) {
                 const auto pos = it.value();
                 m_dropTargetPositions.erase(it);
+                setSortMode(-1);
                 emit move(pos.x(), pos.y(), {url});
             }
         }
     });
-
     /*
      * Dropped files may not actually show up as new files, e.g. when we overwrite
      * an existing file. Or files that fail to be listed by the dirLister, or...
@@ -1600,7 +1596,7 @@ void FolderModel::createActions()
     QAction *rename = KStandardAction::renameFile(this, &FolderModel::requestRename, this);
     QAction *trash = KStandardAction::moveToTrash(this, &FolderModel::moveSelectedToTrash, this);
 
-    QAction *emptyTrash = new QAction(QIcon::fromTheme(QStringLiteral("trash-empty")), i18n("&Empty Trash Bin"), this);
+    QAction *emptyTrash = new QAction(QIcon::fromTheme(QStringLiteral("trash-empty")), i18n("&Empty Trash"), this);
     connect(emptyTrash, &QAction::triggered, this, &FolderModel::emptyTrashBin);
 
     QAction *restoreFromTrash = new QAction(i18nc("Restore from trash", "Restore"), this);
@@ -1787,16 +1783,18 @@ void FolderModel::openContextMenu(QQuickItem *visualParent, Qt::KeyboardModifier
         KFileItemListProperties itemProperties(items);
 
         // Start adding the actions:
-        menu->addAction(m_actionCollection.action(QStringLiteral("open")));
+        // "Open" and "Open with" actions
+        m_fileItemActions->setItemListProperties(itemProperties);
+        m_fileItemActions->addOpenWithActionsTo(menu);
         menu->addSeparator();
         menu->addAction(m_actionCollection.action(QStringLiteral("cut")));
         menu->addAction(m_actionCollection.action(QStringLiteral("copy")));
-        menu->addAction(m_actionCollection.action(QStringLiteral("pasteto")));
+        menu->addAction(m_actionCollection.action(QStringLiteral("paste")));
+        menu->addSeparator();
         menu->addAction(m_actionCollection.action(QStringLiteral("rename")));
         menu->addAction(m_actionCollection.action(QStringLiteral("restoreFromTrash")));
 
-        KSharedConfig::Ptr globalConfig = KSharedConfig::openConfig(QStringLiteral("kdeglobals"), KConfig::NoGlobals);
-        KConfigGroup cg(globalConfig, "KDE");
+        KConfigGroup cg(KSharedConfig::openConfig(), "KDE");
         bool showDeleteCommand = cg.readEntry("ShowDeleteCommand", false);
 
         menu->addAction(m_actionCollection.action(QStringLiteral("emptyTrash")));
@@ -1810,9 +1808,8 @@ void FolderModel::openContextMenu(QQuickItem *visualParent, Qt::KeyboardModifier
 
         deleteAction->setVisible(showDeleteCommand || !trashAction->isVisible());
 
-        // "Open with" actions
-        m_fileItemActions->setItemListProperties(itemProperties);
-        m_fileItemActions->addOpenWithActionsTo(menu);
+        menu->addSeparator();
+
         // Service actions
         m_fileItemActions->addServiceActionsTo(menu);
         menu->addSeparator();
@@ -1830,7 +1827,9 @@ void FolderModel::openContextMenu(QQuickItem *visualParent, Qt::KeyboardModifier
 
         // Properties
         if (KPropertiesDialog::canDisplay(items)) {
+            menu->addSeparator();
             QAction *act = new QAction(QIcon::fromTheme(QStringLiteral("document-properties")), i18n("&Properties"), menu);
+            act->setShortcuts({Qt::ALT + Qt::Key_Return, Qt::ALT + Qt::Key_Enter});
             QObject::connect(act, &QAction::triggered, this, &FolderModel::openPropertiesDialog);
             menu->addAction(act);
         }
