@@ -29,8 +29,9 @@ Positioner::Positioner(QObject *parent): QAbstractItemModel(parent)
 , m_enabled(false)
 , m_folderModel(nullptr)
 , m_perStripe(0)
+, m_lastRow(-1)
 , m_ignoreNextTransaction(false)
-, m_deferApplyPositions(false)
+, m_pendingPositions(false)
 , m_updatePositionsTimer(new QTimer(this))
 {
     m_updatePositionsTimer->setSingleShot(true);
@@ -83,6 +84,7 @@ void Positioner::setFolderModel(QObject *folderModel)
         }
 
         m_folderModel = qobject_cast<FolderModel *>(folderModel);
+        connect(m_folderModel, SIGNAL(urlChanged()), this, SLOT(reset()), Qt::UniqueConnection);
 
         if (m_folderModel) {
             connectSignals(m_folderModel);
@@ -128,11 +130,10 @@ void Positioner::setPositions(const QStringList &positions)
 
         emit positionsChanged();
 
-        // Defer applying positions until listing completes.
-        if (m_folderModel->status() == FolderModel::Listing) {
-            m_deferApplyPositions = true;
-        } else {
+        if (!m_proxyToSource.isEmpty()) {
             applyPositions();
+        } else if (m_positions.size() >= 5) {
+            m_pendingPositions = true;
         }
     }
 }
@@ -269,7 +270,7 @@ void Positioner::setRangeSelected(int anchor, int to)
             }
         }
 
-        if (indices.count()) {
+        if (!indices.isEmpty()) {
             m_folderModel->updateSelection(indices, false);
         }
     } else {
@@ -362,11 +363,6 @@ void Positioner::reset()
 }
 
 void Positioner::move(const QVariantList &moves) {
-    // Don't allow moves while listing.
-    if (m_folderModel->status() == FolderModel::Listing) {
-        return;
-    }
-
     QVector<int> fromIndices;
     QVector<int> toIndices;
     QVector<int> sourceRows;
@@ -407,10 +403,8 @@ void Positioner::move(const QVariantList &moves) {
         }
 
         if (!fromIndices.contains(to) && !isBlank(to)) {
-            /* find the next blank space
-             * we won't be happy if we're moving two icons to the same place
-             */
-            while ((!isBlank(to) && from != to) || toIndices.contains(to)) {
+            // find the next blank space
+            while (!isBlank(to) &&  from != to) {
                 to++;
             }
         }
@@ -486,13 +480,6 @@ void Positioner::updatePositions()
     }
 }
 
-void Positioner::sourceStatusChanged()
-{
-    if (m_deferApplyPositions && m_folderModel->status() != FolderModel::Listing) {
-        applyPositions();
-    }
-}
-
 void Positioner::sourceDataChanged(const QModelIndex &topLeft, const QModelIndex &bottomRight,
     const QVector<int>& roles)
 {
@@ -529,15 +516,13 @@ void Positioner::sourceModelReset()
 void Positioner::sourceRowsAboutToBeInserted(const QModelIndex &parent, int start, int end)
 {
     if (m_enabled) {
-        // Don't insert yet if we're waiting for listing to complete to apply
-        // initial positions;
-        if (m_deferApplyPositions) {
-            return;
-        } else if (m_proxyToSource.isEmpty()) {
-            beginInsertRows(parent, start, end);
-            m_beginInsertRowsCalled = true;
+        if (m_proxyToSource.isEmpty()) {
+            if (!m_pendingPositions) {
+                beginInsertRows(parent, start, end);
+                m_beginInsertRowsCalled = true;
 
-            initMaps(end + 1);
+                initMaps(end + 1);
+            }
 
             return;
         }
@@ -627,6 +612,7 @@ void Positioner::sourceRowsAboutToBeRemoved(const QModelIndex &parent, int first
         m_proxyToSource = newProxyToSource;
         m_sourceToProxy = newSourceToProxy;
 
+        m_lastRow = -1;
         int newLast = lastRow();
 
         if (oldLast > newLast) {
@@ -655,9 +641,13 @@ void Positioner::sourceRowsInserted(const QModelIndex &parent, int first, int la
     Q_UNUSED(last)
 
     if (!m_ignoreNextTransaction) {
-        if (m_beginInsertRowsCalled) {
-            endInsertRows();
-            m_beginInsertRowsCalled = false;
+        if (!m_pendingPositions) {
+            if (m_beginInsertRowsCalled) {
+                endInsertRows();
+                m_beginInsertRowsCalled = false;
+            }
+        } else {
+            applyPositions();
         }
     } else {
         m_ignoreNextTransaction = false;
@@ -665,11 +655,7 @@ void Positioner::sourceRowsInserted(const QModelIndex &parent, int first, int la
 
     flushPendingChanges();
 
-    // Don't generate new positions data if we're waiting for listing to
-    // complete to apply initial positions.
-    if (!m_deferApplyPositions) {
-        m_updatePositionsTimer->start();
-    }
+    m_updatePositionsTimer->start();
 }
 
 void Positioner::sourceRowsMoved(const QModelIndex &sourceParent, int sourceStart,
@@ -735,6 +721,7 @@ void Positioner::updateMaps(int proxyIndex, int sourceIndex)
 {
     m_proxyToSource.insert(proxyIndex, sourceIndex);
     m_sourceToProxy.insert(sourceIndex, proxyIndex);
+    m_lastRow = -1;
 }
 
 int Positioner::firstRow() const
@@ -752,9 +739,13 @@ int Positioner::firstRow() const
 int Positioner::lastRow() const
 {
     if (!m_proxyToSource.isEmpty()) {
-        QList<int> keys(m_proxyToSource.keys());
-        qSort(keys);
-        return keys.last();
+        if (m_lastRow != -1) {
+            return m_lastRow;
+        } else {
+            QList<int> keys(m_proxyToSource.keys());
+            qSort(keys);
+            return keys.last();
+        }
     }
 
     return 0;
@@ -777,23 +768,7 @@ int Positioner::firstFreeRow() const
 
 void Positioner::applyPositions()
 {
-    // We were called while the source model is listing. Defer applying positions
-    // until listing completes.
-    if (m_folderModel->status() == FolderModel::Listing) {
-        m_deferApplyPositions = true;
-
-        return;
-    }
-
-
     if (m_positions.size() < 5) {
-        // We were waiting for listing to complete before proxying source rows,
-        // but we don't have positions to apply. Reset to populate.
-        if (m_deferApplyPositions) {
-            m_deferApplyPositions = false;
-            reset();
-        }
-
         return;
     }
 
@@ -893,7 +868,7 @@ void Positioner::applyPositions()
 
     endResetModel();
 
-    m_deferApplyPositions = false;
+    m_pendingPositions = false;
 
     m_updatePositionsTimer->start();
 }
@@ -944,12 +919,6 @@ void Positioner::connectSignals(FolderModel* model)
     connect(model, &QAbstractItemModel::layoutChanged,
             this, &Positioner::sourceLayoutChanged,
             Qt::UniqueConnection);
-    connect(m_folderModel, &FolderModel::urlChanged,
-            this, &Positioner::reset,
-            Qt::UniqueConnection);
-    connect(m_folderModel, &FolderModel::statusChanged,
-            this, &Positioner::sourceStatusChanged,
-            Qt::UniqueConnection);
 }
 
 void Positioner::disconnectSignals(FolderModel* model)
@@ -972,8 +941,4 @@ void Positioner::disconnectSignals(FolderModel* model)
             this, &Positioner::sourceRowsRemoved);
     disconnect(model, &QAbstractItemModel::layoutChanged,
             this, &Positioner::sourceLayoutChanged);
-    disconnect(m_folderModel, &FolderModel::urlChanged,
-            this, &Positioner::reset);
-    disconnect(m_folderModel, &FolderModel::statusChanged,
-            this, &Positioner::sourceStatusChanged);
 }
