@@ -39,7 +39,7 @@ class FOLDERPLUGIN_TESTS_EXPORT Positioner : public QAbstractItemModel
 
     public:
         explicit Positioner(QObject *parent = nullptr);
-        ~Positioner();
+        ~Positioner() override;
 
         bool enabled() const;
         void setEnabled(bool enabled);
@@ -93,7 +93,6 @@ class FOLDERPLUGIN_TESTS_EXPORT Positioner : public QAbstractItemModel
 
     private Q_SLOTS:
         void updatePositions();
-        void sourceStatusChanged();
         void sourceDataChanged(const QModelIndex &topLeft, const QModelIndex &bottomRight,
             const QVector<int> &roles);
         void sourceModelAboutToBeReset();
@@ -133,7 +132,7 @@ class FOLDERPLUGIN_TESTS_EXPORT Positioner : public QAbstractItemModel
         bool m_ignoreNextTransaction;
 
         QStringList m_positions;
-        bool m_deferApplyPositions;
+        bool m_pendingPositions;
         QTimer *m_updatePositionsTimer;
 
         QHash<int, int> m_proxyToSource;
