@@ -39,9 +39,9 @@ class FontAASettings : public QObject
     Q_OBJECT
 
     Q_PROPERTY(QAbstractItemModel *subPixelOptionsModel READ subPixelOptionsModel CONSTANT)
-    Q_PROPERTY(int subPixelCurrentIndex READ subPixelCurrentIndex WRITE setSubPixelCurrentIndex NOTIFY subPixelCurrentIndexChanged);
+    Q_PROPERTY(int subPixelCurrentIndex READ subPixelCurrentIndex WRITE setSubPixelCurrentIndex NOTIFY subPixelCurrentIndexChanged)
     Q_PROPERTY(QAbstractItemModel *hintingOptionsModel READ hintingOptionsModel CONSTANT)
-    Q_PROPERTY(int hintingCurrentIndex READ hintingCurrentIndex WRITE setHintingCurrentIndex NOTIFY hintingCurrentIndexChanged);
+    Q_PROPERTY(int hintingCurrentIndex READ hintingCurrentIndex WRITE setHintingCurrentIndex NOTIFY hintingCurrentIndexChanged)
 
     Q_PROPERTY(bool exclude READ exclude WRITE setExclude NOTIFY excludeChanged)
     Q_PROPERTY(int excludeTo READ excludeTo WRITE setExcludeTo NOTIFY excludeToChanged)
@@ -131,7 +131,7 @@ class KFonts : public KQuickAddons::ConfigModule
 
 public:
     KFonts(QObject *parent, const QVariantList &);
-    ~KFonts();
+    ~KFonts() override;
 
     void setGeneralFont(const QFont &font);
     QFont generalFont() const;
@@ -154,9 +154,9 @@ public:
     QObject* fontAASettings() { return m_fontAASettings; }
 
 public Q_SLOTS:
-    void load();
-    void save();
-    void defaults();
+    void load() override;
+    void save() override;
+    void defaults() override;
     Q_INVOKABLE void adjustAllFonts();
 
 Q_SIGNALS:
