@@ -98,8 +98,8 @@ class CFontList : public QAbstractItemModel
 
     static QStringList compact(const QStringList &fonts);
 
-    CFontList(QWidget *parent=0);
-    ~CFontList();
+    CFontList(QWidget *parent=nullptr);
+    ~CFontList() override;
 
     QVariant        data(const QModelIndex &index, int role) const override;
     Qt::ItemFlags   flags(const QModelIndex &index) const override;
@@ -116,9 +116,9 @@ class CFontList : public QAbstractItemModel
     int             row(const CFamilyItem *fam) const { return itsFamilies.indexOf((CFamilyItem *)fam); }
     void            forceNewPreviews();
     const CFamilyItemCont & families() const { return itsFamilies; }
-    QModelIndex     createIndex(int row, int column, void *data = 0) const
+    QModelIndex     createIndex(int row, int column, void *data = nullptr) const
                         { return QAbstractItemModel::createIndex(row, column, data); }
-    bool            hasFamily(const QString &family)  { return NULL!=findFamily(family); }
+    bool            hasFamily(const QString &family)  { return nullptr!=findFamily(family); }
     void            refresh(bool allowSys, bool allowUser);
     bool            allowSys() const      { return itsAllowSys; }
     bool            allowUser() const     { return itsAllowUser; }
@@ -172,8 +172,8 @@ class CFontModelItem
     virtual ~CFontModelItem()                                            { }
 
     CFontModelItem * parent() const                  { return itsParent; }
-    bool             isFamily() const                { return NULL==itsParent; }
-    bool             isFont() const                  { return NULL!=itsParent; }
+    bool             isFamily() const                { return nullptr==itsParent; }
+    bool             isFont() const                  { return nullptr!=itsParent; }
     bool             isSystem() const                { return itsIsSystem; }
     void             setIsSystem(bool sys)           { itsIsSystem=sys; }
     virtual int      rowNumber() const = 0;
@@ -238,7 +238,7 @@ class CFontItem : public CFontModelItem
     public:
 
     CFontItem(CFontModelItem *p, const Style &s, bool sys);
-    virtual ~CFontItem() { }
+    ~CFontItem() override { }
 
     void                              refresh();
     QString                           name() const             { return family()+QString::fromLatin1(", ")+itsStyleName; }
@@ -273,7 +273,7 @@ class CFontListSortFilterProxy : public QSortFilterProxyModel
     public:
 
     CFontListSortFilterProxy(QObject *parent, QAbstractItemModel *model);
-    virtual ~CFontListSortFilterProxy() { }
+    ~CFontListSortFilterProxy() override { }
 
     QVariant         data(const QModelIndex &idx, int role) const override;
     bool             acceptFont(CFontItem *fnt, bool checkFontText) const;
@@ -317,7 +317,7 @@ class CFontListView : public QTreeView
     public:
 
     CFontListView(QWidget *parent, CFontList *model);
-    virtual ~CFontListView() { }
+    ~CFontListView() override { }
 
     void            getFonts(CJobRunner::ItemList &urls, QStringList &fontNames, QSet<Misc::TFont> *fonts,
                              bool selected, bool getEnabled=true, bool getDisabled=true);
