@@ -173,7 +173,7 @@ bool CGroupListItem::addFamilies(QDomElement &elem)
 void CGroupListItem::save(QTextStream &str)
 {
     str << " <" GROUP_TAG " " NAME_ATTR "=\"" << Misc::encodeText(itsName, str) << "\">" << endl;
-    if(itsFamilies.count())
+    if(!itsFamilies.isEmpty())
     {
         QSet<QString>::ConstIterator it(itsFamilies.begin()),
                                      end(itsFamilies.end());
@@ -475,7 +475,7 @@ bool CGroupList::load(const QString &file)
 
 bool CGroupList::save()
 {
-    if(itsModified && save(itsFileName, NULL))
+    if(itsModified && save(itsFileName, nullptr))
     {
         itsTimeStamp=Misc::getTimeStamp(itsFileName);
         return true;
@@ -730,12 +730,12 @@ CGroupListItem * CGroupList::find(const QString &name)
         if((*it)->name()==name)
             return (*it);
 
-    return NULL;
+    return nullptr;
 }
 
 bool CGroupList::exists(const QString &name, bool showDialog)
 {
-    if(NULL!=find(name))
+    if(nullptr!=find(name))
     {
         if(showDialog)
             KMessageBox::error(itsParent, i18n("<qt>A group named <b>\'%1\'</b> already "
@@ -751,7 +751,7 @@ class CGroupListViewDelegate : public QStyledItemDelegate
     public:
 
     CGroupListViewDelegate(QObject *p) : QStyledItemDelegate(p) { }
-    virtual ~CGroupListViewDelegate() { }
+    ~CGroupListViewDelegate() override { }
 
     void paint(QPainter *painter, const QStyleOptionViewItem &option, const QModelIndex &idx) const override
     {
@@ -842,7 +842,7 @@ CGroupListView::CGroupListView(QWidget *parent, CGroupList *model)
                                        this, SIGNAL(print()));
     }
     else
-        itsPrintAct=0L;
+        itsPrintAct= nullptr;
     itsMenu->addSeparator();
     itsExportAct=itsMenu->addAction(QIcon::fromTheme("document-export"), i18n("Export..."),
                                     this, SIGNAL(zip()));
@@ -859,7 +859,7 @@ CGroupListItem::EType CGroupListView::getType()
 {
     QModelIndexList selectedItems(selectedIndexes());
 
-    if(selectedItems.count() && selectedItems.last().isValid())
+    if(!selectedItems.isEmpty() && selectedItems.last().isValid())
     {
         CGroupListItem *grp=static_cast<CGroupListItem *>(selectedItems.last().internalPointer());
 
@@ -987,7 +987,7 @@ void CGroupListView::dropEvent(QDropEvent *event)
                       to(indexAt(event->pos()));
 
         ds >> families;
-        // Are we mvoeing/copying, removing a font from the current group?
+        // Are we moving/copying, removing a font from the current group?
         if(to.isValid() && from.isValid())
         {
             if( ((static_cast<CGroupListItem *>(from.internalPointer()))->isSystem() &&
