@@ -159,7 +159,7 @@ class CProgressBar : public QProgressBar
     CProgressBar(QWidget *p, int h) : QProgressBar(p), itsHeight((int)(h*0.6))
         { setSizePolicy(QSizePolicy::Fixed, QSizePolicy::Fixed); }
 
-    virtual ~CProgressBar() { }
+    ~CProgressBar() override { }
 
     int height() const     { return itsHeight; }
     QSize sizeHint() const override { return QSize(100, itsHeight); }
@@ -173,14 +173,13 @@ int CPushButton::theirHeight=0;
 
 CKCmFontInst::CKCmFontInst(QWidget *parent, const QVariantList&)
             : KCModule(parent),
-              itsPreview(NULL),
+              itsPreview(nullptr),
               itsConfig(KFI_UI_CFG_FILE),
-              itsJob(NULL),
-              itsProgress(NULL),
-              itsUpdateDialog(NULL),
-              itsTempDir(NULL),
-              itsPrintProc(NULL),
-              itsDownloadFontsAct(NULL)
+              itsJob(nullptr),
+              itsProgress(nullptr),
+              itsUpdateDialog(nullptr),
+              itsTempDir(nullptr),
+              itsPrintProc(nullptr)
 {
     setButtons(Help);
 
@@ -217,18 +216,12 @@ CKCmFontInst::CKCmFontInst(QWidget *parent, const QVariantList&)
     fontControlLayout->setMargin(0);
 
     // Toolbar...
-    QAction     *duplicateFontsAct=new QAction(QIcon::fromTheme("system-search"), i18n("Scan for Duplicate Fonts..."), this);
-                //*validateFontsAct=new QAction(QIcon::fromTheme("checkmark"), i18n("Validate Fonts..."), this);
+    duplicateFontsAct=new QAction(QIcon::fromTheme("system-search"), i18n("Scan for Duplicate Fonts..."), this);
+//     validateFontsAct=new QAction(QIcon::fromTheme("checkmark"), i18n("Validate Fonts..."), this);
 
-    if(!Misc::root())
-        itsDownloadFontsAct=new QAction(QIcon::fromTheme("get-hot-new-stuff"), i18n("Get New Fonts..."), this);
-    itsToolsMenu=new KActionMenu(QIcon::fromTheme("system-run"), i18n("Tools"), this);
-    itsToolsMenu->addAction(duplicateFontsAct);
-    //itsToolsMenu->addAction(validateFontsAct);
-    if(itsDownloadFontsAct)
-        itsToolsMenu->addAction(itsDownloadFontsAct);
-    itsToolsMenu->setDelayed(false);
-    toolbar->addAction(itsToolsMenu);
+    toolbar->addAction(duplicateFontsAct);
+//     toolbar->addAction(validateFontsAct);
+    toolbar->setToolButtonStyle(Qt::ToolButtonFollowStyle);
     itsFilter=new CFontFilter(toolbarWidget);
 
     // Details - Groups...
@@ -291,8 +284,11 @@ CKCmFontInst::CKCmFontInst(QWidget *parent, const QVariantList&)
     itsFontListView=new CFontListView(itsPreviewSplitter, itsFontList);
     itsFontListView->setSizePolicy(QSizePolicy::MinimumExpanding, QSizePolicy::MinimumExpanding);
 
-    itsAddFontControl=new CPushButton(KGuiItem(i18n("Add..."), "list-add",
-                                               i18n("Install fonts")),
+    itsAddFontControl=new CPushButton(KGuiItem(i18n("Install from File..."), "document-import",
+                                               i18n("Install fonts from a local file")),
+                                      fontControlWidget);
+    itsGetNewFontsControl=new CPushButton(KGuiItem(i18n("Get New Fonts..."), "get-hot-new-stuff",
+                                               i18n("Download new fonts")),
                                       fontControlWidget);
 
     itsDeleteFontControl=new CPushButton(KGuiItem(i18n("Delete"), "edit-delete",
@@ -314,12 +310,13 @@ CKCmFontInst::CKCmFontInst(QWidget *parent, const QVariantList&)
     mainLayout->addWidget(toolbarWidget);
     mainLayout->addWidget(itsGroupSplitter);
 
-    fontControlLayout->addWidget(itsAddFontControl);
     fontControlLayout->addWidget(itsDeleteFontControl);
     fontControlLayout->addWidget(itsStatusLabel);
     fontControlLayout->addItem(new QSpacerItem(0, itsListingProgress->height()+4,
                                                QSizePolicy::Fixed, QSizePolicy::Fixed));
     fontControlLayout->addWidget(itsListingProgress);
+    fontControlLayout->addWidget(itsAddFontControl);
+    fontControlLayout->addWidget(itsGetNewFontsControl);
 
     fontsLayout->addWidget(itsPreviewSplitter);
     fontsLayout->addWidget(fontControlWidget);
@@ -396,11 +393,10 @@ CKCmFontInst::CKCmFontInst(QWidget *parent, const QVariantList&)
     connect(itsEnableGroupControl, SIGNAL(clicked()), SLOT(enableGroup()));
     connect(itsDisableGroupControl, SIGNAL(clicked()), SLOT(disableGroup()));
     connect(itsAddFontControl, SIGNAL(clicked()), SLOT(addFonts()));
+    connect(itsGetNewFontsControl, SIGNAL(clicked()), SLOT(downloadFonts()));
     connect(itsDeleteFontControl, SIGNAL(clicked()), SLOT(deleteFonts()));
     connect(duplicateFontsAct, SIGNAL(triggered(bool)), SLOT(duplicateFonts()));
     //connect(validateFontsAct, SIGNAL(triggered(bool)), SLOT(validateFonts()));
-    if(itsDownloadFontsAct)
-        connect(itsDownloadFontsAct, SIGNAL(triggered(bool)), SLOT(downloadFonts()));
     connect(itsPreview, SIGNAL(customContextMenuRequested(QPoint)), SLOT(previewMenu(QPoint)));
     connect(itsPreviewList, SIGNAL(showMenu(QPoint)), SLOT(previewMenu(QPoint)));
     connect(itsPreviewSplitter, SIGNAL(splitterMoved(int,int)), SLOT(splitterMoved()));
@@ -462,7 +458,7 @@ void CKCmFontInst::fontsSelected(const QModelIndexList &list)
 {
     if(!itsPreviewHidden)
     {
-        if(list.count())
+        if(!list.isEmpty())
         {
             if(list.count()<2)
             {
@@ -494,7 +490,7 @@ void CKCmFontInst::addFonts()
     if (dlg.exec() == QDialog::Accepted)
         list = dlg.selectedUrls();
 
-    if(list.count())
+    if(!list.isEmpty())
     {
         QSet<QUrl>           urls;
         QList<QUrl>::Iterator it(list.begin()),
@@ -522,16 +518,16 @@ void CKCmFontInst::addFonts()
                     urls.insert(url);
             }
         }
-        if(urls.count())
+        if(!urls.isEmpty())
             addFonts(urls);
         delete itsTempDir;
-        itsTempDir=NULL;
+        itsTempDir=nullptr;
     }
 }
 
 void CKCmFontInst::groupSelected(const QModelIndex &index)
 {
-    CGroupListItem *grp=NULL;
+    CGroupListItem *grp=nullptr;
 
     if(index.isValid())
         grp=static_cast<CGroupListItem *>(index.internalPointer());
@@ -559,8 +555,7 @@ void CKCmFontInst::groupSelected(const QModelIndex &index)
         grp->setValidated();
     }
 
-    if(itsDownloadFontsAct)
-        itsDownloadFontsAct->setEnabled(grp->isPersonal() || grp->isAll());
+    itsGetNewFontsControl->setEnabled(grp->isPersonal() || grp->isAll());
 }
 
 void CKCmFontInst::print(bool all)
@@ -575,7 +570,7 @@ void CKCmFontInst::print(bool all)
 
         itsFontListView->getPrintableFonts(fonts, !all);
 
-        if(fonts.count())
+        if(!fonts.isEmpty())
         {
             CPrintDialog dlg(this);
             KConfigGroup cg(&itsConfig, CFG_GROUP);
@@ -600,7 +595,7 @@ void CKCmFontInst::print(bool all)
                     title = QCoreApplication::applicationName();
 
                 //
-                // If we have lots of fonts to print, pass kfontinst a tempory groups file to print
+                // If we have lots of fonts to print, pass kfontinst a temporary groups file to print
                 // instead of passing font by font...
                 if(useFile)
                 {
@@ -711,7 +706,7 @@ void CKCmFontInst::moveFonts()
     QStringList          fontNames;
 
     itsDeletedFonts.clear();
-    itsFontListView->getFonts(urls, fontNames, NULL, true);
+    itsFontListView->getFonts(urls, fontNames, nullptr, true);
 
     if(urls.isEmpty())
         KMessageBox::information(this, i18n("You did not select anything to move."),
@@ -779,7 +774,7 @@ void CKCmFontInst::zipGroup()
 
                     files=itsFontListView->getFiles();
 
-                    if(files.count())
+                    if(!files.isEmpty())
                     {
                         QMap<QString, QString>                map=Misc::getFontFileMap(files);
                         QMap<QString, QString>::ConstIterator it(map.constBegin()),
@@ -869,7 +864,7 @@ void CKCmFontInst::downloadFonts()
     KNS3::DownloadDialog *newStuff = new KNS3::DownloadDialog("kfontinst.knsrc", this);
     newStuff->exec();
 
-    if(newStuff->changedEntries().count())  // We have new fonts, so need to reconfigure fontconfig...
+    if(!newStuff->changedEntries().isEmpty())  // We have new fonts, so need to reconfigure fontconfig...
     {
         // Ask dbus helper for the current fonts folder name...
         // We then sym-link our knewstuff3 download folder into the fonts folder...
@@ -1019,7 +1014,7 @@ void CKCmFontInst::setStatusBar()
 
 void CKCmFontInst::addFonts(const QSet<QUrl> &src)
 {
-    if(src.count() && !itsGroupListView->isCustom())
+    if(!src.isEmpty() && !itsGroupListView->isCustom())
     {
         bool system;
 
@@ -1078,7 +1073,7 @@ void CKCmFontInst::addFonts(const QSet<QUrl> &src)
             itsProgress->setAutoClose(true);
         }
 
-        itsProgress->setCancelButton(0);
+        itsProgress->setCancelButton(nullptr);
         itsProgress->setMinimumDuration(500);
         itsProgress->setRange(0, src.size());
         itsProgress->setValue(0);
@@ -1122,7 +1117,7 @@ void CKCmFontInst::addFonts(const QSet<QUrl> &src)
 
 void CKCmFontInst::removeDeletedFontsFromGroups()
 {
-    if(itsDeletedFonts.count())
+    if(!itsDeletedFonts.isEmpty())
     {
         QSet<QString>::Iterator it(itsDeletedFonts.begin()),
                                 end(itsDeletedFonts.end());
@@ -1177,7 +1172,7 @@ void CKCmFontInst::toggleFonts(bool enable, const QString &grp)
     CJobRunner::ItemList urls;
     QStringList          fonts;
 
-    itsFontListView->getFonts(urls, fonts, NULL, grp.isEmpty(), !enable, enable);
+    itsFontListView->getFonts(urls, fonts, nullptr, grp.isEmpty(), !enable, enable);
 
     if(urls.isEmpty())
         KMessageBox::information(this,
@@ -1272,7 +1267,7 @@ void CKCmFontInst::doCmd(CJobRunner::ECommand cmd, const CJobRunner::ItemList &u
     CFcEngine::setDirty();
     setStatusBar();
     delete itsTempDir;
-    itsTempDir=NULL;
+    itsTempDir=nullptr;
     itsFontListView->repaint();
     removeDeletedFontsFromGroups();
 }
