@@ -375,15 +375,15 @@ static void createGtkrc( bool exportColors, const QPalette& cg, bool exportGtkTh
         // tooltips don't have the standard background color
         t << "style \"ToolTip\"" << endl;
         t << "{" << endl;
-        t << "  bg[NORMAL] = " << color( cg.color( QPalette::ToolTipBase ) ) << endl;
-        t << "  base[NORMAL] = " << color( cg.color( QPalette::ToolTipBase ) ) << endl;
-        t << "  text[NORMAL] = " << color( cg.color( QPalette::ToolTipText ) ) << endl;
-        t << "  fg[NORMAL] = " << color( cg.color( QPalette::ToolTipText ) ) << endl;
+        QPalette group = QToolTip::palette();
+        t << "  bg[NORMAL] = " << color( group.color( QPalette::Active, QPalette::Background ) ) << endl;
+        t << "  base[NORMAL] = " << color( group.color( QPalette::Active, QPalette::Base ) ) << endl;
+        t << "  text[NORMAL] = " << color( group.color( QPalette::Active, QPalette::Text ) ) << endl;
+        t << "  fg[NORMAL] = " << color( group.color( QPalette::Active, QPalette::Foreground ) ) << endl;
         t << "}" << endl;
         t << endl;
         t << "widget \"gtk-tooltip\" style \"ToolTip\"" << endl;
         t << "widget \"gtk-tooltips\" style \"ToolTip\"" << endl;
-        t << "widget \"gtk-tooltip*\" style \"ToolTip\"" << endl;
         t << endl;
 
 
@@ -606,7 +606,7 @@ void runRdb( uint flags )
         static Atom qt_settings_timestamp = 0;
         if (!qt_settings_timestamp) {
             QString atomname(QStringLiteral("_QT_SETTINGS_TIMESTAMP_"));
-            atomname += XDisplayName( 0 ); // Use the $DISPLAY envvar.
+            atomname += XDisplayName( nullptr ); // Use the $DISPLAY envvar.
             qt_settings_timestamp = XInternAtom( QX11Info::display(), atomname.toLatin1(), False);
         }
 
