@@ -47,7 +47,7 @@ KCMSplashScreen::KCMSplashScreen(QObject* parent, const QVariantList& args)
     , m_configGroup(m_config.group("KSplash"))
 {
     qmlRegisterType<QStandardItemModel>();
-    KAboutData* about = new KAboutData(QStringLiteral("kcm_splashscreen"), i18n("Configure Splash screen details"),
+    KAboutData* about = new KAboutData(QStringLiteral("kcm_splashscreen"), i18n("Choose the splash screen theme"),
                                        QStringLiteral("0.1"), QString(), KAboutLicense::LGPL);
     about->addAuthor(i18n("Marco Martin"), QString(), QStringLiteral("mart@kde.org"));
     setAboutData(about);
@@ -111,10 +111,10 @@ void KCMSplashScreen::setSelectedPlugin(const QString &plugin)
 
 void KCMSplashScreen::getNewClicked()
 {
-    KNS3::DownloadDialog dialog("ksplash.knsrc", 0);
+    KNS3::DownloadDialog dialog("ksplash.knsrc", nullptr);
     if (dialog.exec()) {
         KNS3::Entry::List list = dialog.changedEntries();
-        if (list.count() > 0) {
+        if (!list.isEmpty()) {
             loadModel();
         }
     }
@@ -203,7 +203,7 @@ void KCMSplashScreen::test(const QString &plugin)
     QStringList arguments;
     arguments << plugin << QStringLiteral("--test");
     if (proc.execute(QStringLiteral("ksplashqml"), arguments)) {
-        QMessageBox::critical(0, i18n("Error"), i18n("Failed to successfully test the splash screen."));
+        QMessageBox::critical(nullptr, i18n("Error"), i18n("Failed to successfully test the splash screen."));
     }
 }
 
